<?php

/*
Plugin Name: Light SEO
Plugin URI: http://www.aldentorres.com/light-seo-wordpress-plugin
Description: Fork of the popular All in One SEO Pack plugin. Focused in creating a clean plugin, with emphasis in source code's good practices.
Version: 0.0.4
Author: Alden Torres
Author URI: http://www.aldentorres.com
*/

/*
Copyright (C) 2008-2009 Alden Torres  (email : aldenml@yahoo.com)
Original code by Michael Torbert, semperfiwebdesign.com (michael AT semperfiwebdesign DOT com)
Original code by uberdose of uberdose.com

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/*******************************************************************************************************/

if ( ! defined( 'WP_CONTENT_URL' ) )
    define( 'WP_CONTENT_URL', get_option( 'siteurl' ) . '/wp-content' );
if ( ! defined( 'WP_CONTENT_DIR' ) )
    define( 'WP_CONTENT_DIR', ABSPATH . 'wp-content' );
if ( ! defined( 'WP_PLUGIN_URL' ) )
    define( 'WP_PLUGIN_URL', WP_CONTENT_URL. '/plugins' );
if ( ! defined( 'WP_PLUGIN_DIR' ) )
    define( 'WP_PLUGIN_DIR', WP_CONTENT_DIR . '/plugins' );

class Light_SEO
{	
	/** Max numbers of chars in auto-generated description */
	var $maximum_description_length = 160;
 	
 	/** Minimum number of chars an excerpt should be so that it can be used
 	 * as description. Touch only if you know what you're doing
 	 */
 	var $minimum_description_length = 1;

 	var $ob_start_detected = false;
 
	var $title_start = -1;

	var $title_end = -1;
 	
 	/** The title before rewriting */
 	var $orig_title = '';
 	 	
 	/** Filename of log file. */
 	var $log_file;

 	/** Flag whether there should be logging. */
 	var $do_log;

	/**
	 * Constructor.
	 */
	function Light_SEO()
	{
		global $lightseop_options;

		$this->log_file = dirname(__FILE__) . '/light_seo.log';
		if ($lightseop_options['lightseo_do_log'])
		{
			$this->do_log = true;
		}
		else
		{
			$this->do_log = false;
		}
	}
	
	/**      
	 * Convert a string to lower case.
	 * Originally, this function relied their functionality in a global UTF-8 character table.
	 * I will take my chances with a standard function.
	 */
	function strtolower($str)
	{
		return mb_strtolower($str, 'UTF-8');
	}
	
	/**      
	 * Convert a string to upper case.
	 * Originally, this function relied their functionality in a global UTF-8 character table.
	 * I will take my chances with a standard function.
	 */
	function strtoupper($str)
	{
		return mb_strtoupper($str, 'UTF-8');
	}
	
	/**
	 * Make a string's first character uppercase.
	 */
	function capitalize($str)
	{
		return mb_convert_case($str, MB_CASE_TITLE, 'UTF-8');
	}
	
	function is_static_front_page()
	{
		global $wp_query;
		
		$post = $wp_query->get_queried_object();
		
		return get_option('show_on_front') == 'page' && is_page() && $post->ID == get_option('page_on_front');
	}
	
	function is_static_posts_page()
	{
		global $wp_query;
		
		$post = $wp_query->get_queried_object();
		
		return get_option('show_on_front') == 'page' && is_home() && $post->ID == get_option('page_for_posts');
	}
	
	function template_redirect()
	{
		global $wp_query;
		global $lightseop_options;

		$post = $wp_query->get_queried_object();

		if ($this->lightseop_mrt_exclude_this_page())
		{
			return;
		}

		if (is_feed())
		{
			return;
		}

		if (is_single() || is_page())
		{
			$lightseo_disable = htmlspecialchars(stripcslashes(get_post_meta($post->ID, '_lightseop_disable', true)));
			
			if ($lightseo_disable)
			{
				return;
			}
		}

		if ($lightseop_options['lightseo_rewrite_titles'])
		{
			ob_start(array($this, 'output_callback_for_title'));
		}
	}
	
	function lightseop_mrt_exclude_this_page()
	{
		global $lightseop_options;

		$currenturl = trim($_SERVER['REQUEST_URI'],'/');
	
		$excludedstuff = explode(',',$lightseop_options['lightseo_ex_pages']);

		foreach($excludedstuff as $exedd)
		{
			$exedd = trim($exedd);

			if($exedd)
			{
				if(stristr($currenturl, $exedd))
				{
					return true;
				}
			}
		}
		
		return false;
	}
	
	function output_callback_for_title($content)
	{
		return $this->rewrite_title($content);
	}


	/**
	 * Runs after WordPress admin has finished loading but before any headers are sent.
	 * Useful for intercepting $_GET or $_POST triggers. 
	 */
	function init()
	{
		// Loads the plugin's translated strings. 
		if ( !defined('WP_PLUGIN_DIR') )
		{
			load_plugin_textdomain('light_seo', str_replace( ABSPATH, '', dirname(__FILE__)));
		}
		else
		{
			load_plugin_textdomain('light_seo', false, dirname(plugin_basename(__FILE__)));
		}
	}
	
	function get_base()
	{
   		 return '/'.end(explode('/', str_replace(array('\\', '/lightseo.php'), array('/', ''), __FILE__)));
	}

	function wp_head()
	{
		if (is_feed()) // ignore logic if it's a feed
		{
			return;
		}
		
		global $wp_query;
		global $lightseop_options;
		
		$post = $wp_query->get_queried_object();
		$meta_string = null;
		
		if ($this->is_static_posts_page())
		{
			$title = strip_tags(apply_filters('single_post_title', $post->post_title));
		}

		if (is_single() || is_page())
		{
			$lightseo_disable = htmlspecialchars(stripcslashes(get_post_meta($post->ID, '_lightseop_disable', true)));
			
			if ($lightseo_disable)
			{
				return;
			}
		}
		
		if ($this->lightseop_mrt_exclude_this_page() == TRUE)
		{
			return;
		}
		
		if ($lightseop_options['lightseo_rewrite_titles'])
		{
			// make the title rewrite as short as possible
			if (function_exists('ob_list_handlers'))
			{
				$active_handlers = ob_list_handlers();
			}
			else
			{
				$active_handlers = array();
			}
			
			if ((sizeof($active_handlers) > 0) &&
				(strtolower($active_handlers[sizeof($active_handlers) - 1]) ==
				strtolower('Light_SEO::output_callback_for_title')))
			{
				ob_end_flush();
			}
			else
			{
				$this->log("another plugin interfering?");
				// if we get here there *could* be trouble with another plugin :(
				$this->ob_start_detected = true;
				
				if (function_exists('ob_list_handlers'))
				{
					foreach (ob_list_handlers() as $handler)
					{
						$this->log("detected output handler $handler");
					}
				}
			}
		}
		
		if ((is_home() && $lightseop_options['lightseo_home_keywords'] &&
			!$this->is_static_posts_page()) || $this->is_static_front_page())
		{
			$keywords = trim($this->internationalize($lightseop_options['lightseo_home_keywords']));
		}
		elseif ($this->is_static_posts_page() && !$lightseop_options['lightseo_dynamic_postspage_keywords']) // and if option = use page set keywords instead of keywords from recent posts
		{
			$keywords = stripcslashes($this->internationalize(get_post_meta($post->ID, "_lightseop_keywords", true)));
//			$keywords =	$this->get_unique_keywords($keywords);
		}
		else
		{
			$keywords = $this->get_all_keywords();
		}
		
		if (is_single() || is_page() || $this->is_static_posts_page())
		{
			if ($this->is_static_front_page())
			{
				$description = trim(stripcslashes($this->internationalize($lightseop_options['lightseo_home_description'])));
			}
			else
			{
				$description = $this->get_post_description($post);
				$description = apply_filters('lightseop_description',$description);
			}
		}
		elseif (is_home())
		{
			$description = trim(stripcslashes($this->internationalize($lightseop_options['lightseo_home_description'])));
		}
		elseif (is_category())
		{
			$description = $this->internationalize(category_description());
		}
		
		if (isset($description) && (strlen($description) > $this->minimum_description_length) &&
			!(is_home() && is_paged()))
		{
			$description = trim(strip_tags($description));
			$description = str_replace('"', '', $description);
			
			// replace newlines on mac / windows?
			$description = str_replace("\r\n", ' ', $description);
			
			// maybe linux uses this alone
			$description = str_replace("\n", ' ', $description);
			
			if (isset($meta_string))
			{
				//$meta_string .= "\n";
			}
			else
			{
				$meta_string = '';
			}
			
			// description format
			$description_format = $lightseop_options['lightseo_description_format'];

			if (!isset($description_format) || empty($description_format))
			{
				$description_format = "%description%";
			}
			
			$description = str_replace('%description%', $description, $description_format);
			$description = str_replace('%blog_title%', get_bloginfo('name'), $description);
			$description = str_replace('%blog_description%', get_bloginfo('description'), $description);
			$description = str_replace('%wp_title%', $this->get_original_title(), $description);
			//$description = html_entity_decode($description, ENT_COMPAT, get_bloginfo('charset')); 
            
			if($lightseop_options['lightseo_can'] && is_attachment())
			{
				$url = $this->lightseo_mrt_get_url($wp_query);
                
				if ($url)
				{
					preg_match_all('/(\d+)/', $url, $matches);

					if (is_array($matches))
					{
						$uniqueDesc = join('',$matches[0]);
					}
				}
				
				$description .= ' ' . $uniqueDesc;
			}
			
			$meta_string .= sprintf("<meta name=\"description\" content=\"%s\" />", $description);
		}
		
		$keywords = apply_filters('lightseop_keywords', $keywords);
		
		if (isset($keywords) && !empty($keywords) && !(is_home() && is_paged()))
		{
			if (isset($meta_string))
			{
				$meta_string .= "\n";
			}
			
			$meta_string .= sprintf("<meta name=\"keywords\" content=\"%s\" />", $keywords);
		}

		if (function_exists('is_tag'))
		{
			$is_tag = is_tag();
		}
		
		if ((is_category() && $lightseop_options['lightseo_category_noindex']) ||
			(!is_category() && is_archive() &&!$is_tag && $lightseop_options['lightseo_archive_noindex']) ||
			($lightseop_options['lightseo_tags_noindex'] && $is_tag))
		{
			if (isset($meta_string))
			{
				$meta_string .= "\n";
			}
			
			$meta_string .= '<meta name="robots" content="noindex,follow" />';
		}
		
		$page_meta = stripcslashes($lightseop_options['lightseo_page_meta_tags']);
		$post_meta = stripcslashes($lightseop_options['lightseo_post_meta_tags']);
		$home_meta = stripcslashes($lightseop_options['lightseo_home_meta_tags']);
		
		if (is_page() && isset($page_meta) && !empty($page_meta) || $this->is_static_posts_page())
		{
			if (isset($meta_string))
			{
				$meta_string .= "\n";
			}
			
			echo "\n$page_meta";
		}
		
		if (is_single() && isset($post_meta) && !empty($post_meta))
		{
			if (isset($meta_string))
			{
				$meta_string .= "\n";
			}
			
			$meta_string .= "$post_meta";
		}
		
		if (is_home() && !empty($home_meta))
		{
			if (isset($meta_string))
			{
				$meta_string .= "\n";
			}
			
			$meta_string .= "$home_meta";
		}
		
		if ($meta_string != null)
		{
			echo "$meta_string\n";
		}
		
		if($lightseop_options['lightseo_can'])
		{
			$url = $this->lightseo_mrt_get_url($wp_query);
			
			if ($url)
			{
				$url = apply_filters('lightseop_canonical_url',$url);
			
				echo "".'<link rel="canonical" href="'.$url.'" />'."\n";
			}
		}
	}
	
	function lightseo_mrt_get_url($query)
	{
		global $lightseop_options;
		
		if ($query->is_404 || $query->is_search) {
			return false;
		}
		
		$haspost = count($query->posts) > 0;
		$has_ut = function_exists('user_trailingslashit');

		if (get_query_var('m'))
		{
			$m = preg_replace('/[^0-9]/', '', get_query_var('m'));
			
			switch (strlen($m))
			{
			case 4:
				$link = get_year_link($m);
				break;
			case 6:
				$link = get_month_link(substr($m, 0, 4), substr($m, 4, 2));
				break;
			case 8:
				$link = get_day_link(substr($m, 0, 4), substr($m, 4, 2), substr($m, 6, 2));
				break;
			default:
				return false;
			}
		}
		elseif (($query->is_single || $query->is_page) && $haspost)
		{
			$post = $query->posts[0];
			$link = get_permalink($post->ID);
			$link = $this->yoast_get_paged($link); 
/*	        if ($page && $page > 1) {
	            $link = trailingslashit($link) . "page/". "$page";
	            if ($has_ut) {
	                $link = user_trailingslashit($link, 'paged');
	            } else {
	                $link .= '/';
	            }
	        }
	        if ($query->is_page && ('page' == get_option('show_on_front')) && 
	            $post->ID == get_option('page_on_front'))
	        {
	            $link = trailingslashit($link);
	        }*/
		}
		elseif ($query->is_author && $haspost)
		{
			$author = get_userdata(get_query_var('author'));

			if ($author === false)
				return false;

			$link = get_author_link(false, $author->ID, $author->user_nicename);
		}
		elseif ($query->is_category && $haspost)
		{
			$link = get_category_link(get_query_var('cat'));
			$link = $this->yoast_get_paged($link);
		}
		elseif ($query->is_tag  && $haspost)
		{
			$tag = get_term_by('slug',get_query_var('tag'),'post_tag');
			
			if (!empty($tag->term_id))
			{
				$link = get_tag_link($tag->term_id);
			}
			
			$link = $this->yoast_get_paged($link);			
		}
		elseif ($query->is_day && $haspost)
		{
			$link = get_day_link(get_query_var('year'), get_query_var('monthnum'), get_query_var('day'));
		}
		elseif ($query->is_month && $haspost)
		{
			$link = get_month_link(get_query_var('year'), get_query_var('monthnum'));
		}
		elseif ($query->is_year && $haspost)
		{
			$link = get_year_link(get_query_var('year'));
		}
		elseif ($query->is_home)
		{
			if ((get_option('show_on_front') == 'page') && ($pageid = get_option('page_for_posts')))
			{
				$link = get_permalink($pageid);
				$link = $this->yoast_get_paged($link);
				$link = trailingslashit($link);
			}
			else
			{
				$link = get_option('home');
				$link = $this->yoast_get_paged($link);
				$link = trailingslashit($link);
			}
		}
		else
		{
			return false;
		}
		
		return $link;
	}
	
	function yoast_get_paged($link)
	{
		$page = get_query_var('paged');

		if ($page && $page > 1)
		{
			$link = trailingslashit($link) ."page/". "$page";

			if ($has_ut)
			{
				$link = user_trailingslashit($link, 'paged');
			}
			else
			{
				$link .= '/';
			}
		}

		return $link;
	}
	
	function get_post_description($post)
	{
		global $lightseop_options;
		
		$description = trim(stripcslashes($this->internationalize(get_post_meta($post->ID, "_lightseop_description", true))));
		
		if (!$description)
		{
			$description = $this->trim_excerpt_without_filters_full_length($this->internationalize($post->post_excerpt));
			
			if (!$description && $lightseop_options["lightseo_generate_descriptions"])
			{
				$description = $this->trim_excerpt_without_filters($this->internationalize($post->post_content));
			}				
		}
		
		// "internal whitespace trim"
		$description = preg_replace("/\s\s+/", " ", $description);
		
		return $description;
	}
	
	function replace_title($content, $title)
	{
		$title = trim(strip_tags($title));
		
		$title_tag_start = "<title>";
		$title_tag_end = "</title>";
		$len_start = strlen($title_tag_start);
		$len_end = strlen($title_tag_end);
		$title = stripcslashes(trim($title));
		$start = strpos($content, $title_tag_start);
		$end = strpos($content, $title_tag_end);
		
		$this->title_start = $start;
		$this->title_end = $end;
		$this->orig_title = $title;
		
		if ($start && $end)
		{
			$header = substr($content, 0, $start + $len_start) . $title .  substr($content, $end);
		}
		else
		{
			// this breaks some sitemap plugins (like wpg2)
			//$header = $content . "<title>$title</title>";
			
			$header = $content;
		}
		
		return $header;
	}
	
	function internationalize($in)
	{
		if (function_exists('langswitch_filter_langs_with_message'))
		{
			$in = langswitch_filter_langs_with_message($in);
		}
		
		if (function_exists('polyglot_filter'))
		{
			$in = polyglot_filter($in);
		}
		
		if (function_exists('qtrans_useCurrentLanguageIfNotFoundUseDefaultLanguage'))
		{
			$in = qtrans_useCurrentLanguageIfNotFoundUseDefaultLanguage($in);
		}

		$in = apply_filters('localization', $in);

		return $in;
	}
	
	/** @return The original title as delivered by WP (well, in most cases) */
	function get_original_title()
	{
		global $wp_query;
		global $lightseop_options;
		
		if (!$wp_query)
		{
			return null;	
		}
		
		$post = $wp_query->get_queried_object();
		
		// the_search_query() is not suitable, it cannot just return
		global $s;

		$title = null;
		
		if (is_home())
		{
			$title = get_option('blogname');
		}
		elseif (is_single())
		{
			$title = $this->internationalize(wp_title('', false));
		}
		elseif (is_search() && isset($s) && !empty($s))
		{
			if (function_exists('attribute_escape'))
			{
				$search = attribute_escape(stripcslashes($s));
			}
			else
			{
				$search = wp_specialchars(stripcslashes($s), true);
			}
			
			$search = $this->capitalize($search);
			$title = $search;
		}
		elseif (is_category() && !is_feed())
		{
			$category_description = $this->internationalize(category_description());
			$category_name = ucwords($this->internationalize(single_cat_title('', false)));
			$title = $category_name;
		}
		elseif (is_page())
		{
			$title = $this->internationalize(wp_title('', false));
		}
		elseif (function_exists('is_tag') && is_tag())
		{
			$tag = $this->internationalize(wp_title('', false));

			if ($tag)
			{
				$title = $tag;
			}
		}
		else if (is_archive())
		{
			$title = $this->internationalize(wp_title('', false));
		}
		else if (is_404())
		{
			$title_format = $lightseop_options['lightseo_404_title_format'];

			$new_title = str_replace('%blog_title%', $this->internationalize(get_bloginfo('name')), $title_format);
			$new_title = str_replace('%blog_description%', $this->internationalize(get_bloginfo('description')), $new_title);
			$new_title = str_replace('%request_url%', $_SERVER['REQUEST_URI'], $new_title);
			$new_title = str_replace('%request_words%', $this->request_as_words($_SERVER['REQUEST_URI']), $new_title);
			
			$title = $new_title;
		}

		return trim($title);
	}
	
	function paged_title($title)
	{
		// the page number if paged
		global $paged;
		global $lightseop_options;
		// simple tagging support
		global $STagging;

		if (is_paged() || (isset($STagging) && $STagging->is_tag_view() && $paged))
		{
			$part = $this->internationalize($lightseop_options['lightseo_paged_format']);

			if (isset($part) || !empty($part))
			{
				$part = " " . trim($part);
				$part = str_replace('%page%', $paged, $part);
				$this->log("paged_title() [$title] [$part]");
				$title .= $part;
			}
		}

		return $title;
	}

	function rewrite_title($header)
	{
		global $lightseop_options;
		global $wp_query;
		
		if (!$wp_query)
		{
			return $header;	
		}
		
		$post = $wp_query->get_queried_object();
		
		// the_search_query() is not suitable, it cannot just return
		global $s;
		
		global $STagging;

		if (is_home() && !$this->is_static_posts_page())
		{
			$title = $this->internationalize($lightseop_options['lightseo_home_title']);
			
			if (empty($title))
			{
				$title = $this->internationalize(get_option('blogname'));
			}

			$title = $this->paged_title($title);
			$header = $this->replace_title($header, $title);
		}
		else if (is_attachment())
		{
			$title = get_the_title($post->post_parent).' '.$post->post_title.' – '.get_option('blogname');
			$header = $this->replace_title($header,$title);
		}
		else if (is_single())
		{
			// we're not in the loop :(
			$authordata = get_userdata($post->post_author);
			$categories = get_the_category();
			$category = '';
			
			if (count($categories) > 0)
			{
				$category = $categories[0]->cat_name;
			}

			$title = $this->internationalize(get_post_meta($post->ID, "_lightseop_title", true));
			
			if (!$title)
			{
				$title = $this->internationalize(get_post_meta($post->ID, "title_tag", true));
				
				if (!$title)
				{
					$title = $this->internationalize(wp_title('', false));
				}
			}

			$title_format = $lightseop_options['lightseo_post_title_format'];

			$new_title = str_replace('%blog_title%', $this->internationalize(get_bloginfo('name')), $title_format);
			$new_title = str_replace('%blog_description%', $this->internationalize(get_bloginfo('description')), $new_title);
			$new_title = str_replace('%post_title%', $title, $new_title);
			$new_title = str_replace('%category%', $category, $new_title);
			$new_title = str_replace('%category_title%', $category, $new_title);
			$new_title = str_replace('%post_author_login%', $authordata->user_login, $new_title);
			$new_title = str_replace('%post_author_nicename%', $authordata->user_nicename, $new_title);
			$new_title = str_replace('%post_author_firstname%', ucwords($authordata->first_name), $new_title);
			$new_title = str_replace('%post_author_lastname%', ucwords($authordata->last_name), $new_title);

			$title = $new_title;
			$title = trim($title);
			$title = apply_filters('lightseop_title_single',$title);

			$header = $this->replace_title($header, $title);
		}
		elseif (is_search() && isset($s) && !empty($s))
		{
			if (function_exists('attribute_escape'))
			{
				$search = attribute_escape(stripcslashes($s));
			}
			else
			{
				$search = wp_specialchars(stripcslashes($s), true);
			}

			$search = $this->capitalize($search);
			$title_format = $lightseop_options['lightseo_search_title_format'];

			$title = str_replace('%blog_title%', $this->internationalize(get_bloginfo('name')), $title_format);
			$title = str_replace('%blog_description%', $this->internationalize(get_bloginfo('description')), $title);
			$title = str_replace('%search%', $search, $title);
			
			$header = $this->replace_title($header, $title);
		}
		elseif (is_category() && !is_feed())
		{
			$category_description = $this->internationalize(category_description());

			if($lightseop_options['lightseo_cap_cats'])
			{
				$category_name = ucwords($this->internationalize(single_cat_title('', false)));
			}
			else
			{
				$category_name = $this->internationalize(single_cat_title('', false));
			}			
			
			//$category_name = ucwords($this->internationalize(single_cat_title('', false)));
			$title_format = $lightseop_options['lightseo_category_title_format'];
            
			$title = str_replace('%category_title%', $category_name, $title_format);
			$title = str_replace('%category_description%', $category_description, $title);
			$title = str_replace('%blog_title%', $this->internationalize(get_bloginfo('name')), $title);
			$title = str_replace('%blog_description%', $this->internationalize(get_bloginfo('description')), $title);
			$title = $this->paged_title($title);
			
			$header = $this->replace_title($header, $title);
		}
		elseif (is_page() || $this->is_static_posts_page())
		{
			// we're not in the loop :(
			$authordata = get_userdata($post->post_author);

			if ($this->is_static_front_page())
			{
				if ($this->internationalize($lightseop_options['lightseo_home_title']))
				{
					//home title filter
					$home_title = $this->internationalize($lightseop_options['lightseo_home_title']);
					$home_title = apply_filters('lightseop_home_page_title',$home_title);
					
					$header = $this->replace_title($header, $home_title);
				}
			}
			else
			{
				$title = $this->internationalize(get_post_meta($post->ID, "_lightseop_title", true));
				
				if (!$title)
				{
					$title = $this->internationalize(wp_title('', false));
				}

				$title_format = $lightseop_options['lightseo_page_title_format'];

				$new_title = str_replace('%blog_title%', $this->internationalize(get_bloginfo('name')), $title_format);
				$new_title = str_replace('%blog_description%', $this->internationalize(get_bloginfo('description')), $new_title);
				$new_title = str_replace('%page_title%', $title, $new_title);
				$new_title = str_replace('%page_author_login%', $authordata->user_login, $new_title);
				$new_title = str_replace('%page_author_nicename%', $authordata->user_nicename, $new_title);
				$new_title = str_replace('%page_author_firstname%', ucwords($authordata->first_name), $new_title);
				$new_title = str_replace('%page_author_lastname%', ucwords($authordata->last_name), $new_title);

				$title = trim($new_title);
				$title = apply_filters('lightseop_title_page',$title);

				$header = $this->replace_title($header, $title);
			}
		}
		elseif (function_exists('is_tag') && is_tag())
		{
			$tag = $this->internationalize(wp_title('', false));

			if ($tag)
			{
				$tag = $this->capitalize($tag);
				$title_format = $lightseop_options['lightseo_tag_title_format'];
	            
				$title = str_replace('%blog_title%', $this->internationalize(get_bloginfo('name')), $title_format);
				$title = str_replace('%blog_description%', $this->internationalize(get_bloginfo('description')), $title);
				$title = str_replace('%tag%', $tag, $title);
				$title = $this->paged_title($title);
				
				$header = $this->replace_title($header, $title);
			}
		}
		elseif (isset($STagging) && $STagging->is_tag_view()) // simple tagging support
		{
			$tag = $STagging->search_tag;
			
			if ($tag)
			{
				$tag = $this->capitalize($tag);
				$title_format = $lightseop_options['lightseo_tag_title_format'];

				$title = str_replace('%blog_title%', $this->internationalize(get_bloginfo('name')), $title_format);
				$title = str_replace('%blog_description%', $this->internationalize(get_bloginfo('description')), $title);
				$title = str_replace('%tag%', $tag, $title);
				$title = $this->paged_title($title);

				$header = $this->replace_title($header, $title);
			}
		}
		else if (is_archive())
		{
			$date = $this->internationalize(wp_title('', false));
			$title_format = $lightseop_options['lightseo_archive_title_format'];

			$new_title = str_replace('%blog_title%', $this->internationalize(get_bloginfo('name')), $title_format);
			$new_title = str_replace('%blog_description%', $this->internationalize(get_bloginfo('description')), $new_title);
			$new_title = str_replace('%date%', $date, $new_title);

			$title = trim($new_title);
			$title = $this->paged_title($title);

			$header = $this->replace_title($header, $title);
		}
		else if (is_404())
		{
			$title_format = $lightseop_options['lightseo_404_title_format'];

			$new_title = str_replace('%blog_title%', $this->internationalize(get_bloginfo('name')), $title_format);
			$new_title = str_replace('%blog_description%', $this->internationalize(get_bloginfo('description')), $new_title);
			$new_title = str_replace('%request_url%', $_SERVER['REQUEST_URI'], $new_title);
			$new_title = str_replace('%request_words%', $this->request_as_words($_SERVER['REQUEST_URI']), $new_title);
			$new_title = str_replace('%404_title%', $this->internationalize(wp_title('', false)), $new_title);

			$header = $this->replace_title($header, $new_title);
		}
		
		return $header;
	}
	
	/**
	 * @return User-readable nice words for a given request.
	 */
	function request_as_words($request)
	{
		$request = htmlspecialchars($request);
		$request = str_replace('.html', ' ', $request);
		$request = str_replace('.htm', ' ', $request);
		$request = str_replace('.', ' ', $request);
		$request = str_replace('/', ' ', $request);

		$request_a = explode(' ', $request);
		$request_new = array();

		foreach ($request_a as $token)
		{
			$request_new[] = ucwords(trim($token));
		}

		$request = implode(' ', $request_new);

		return $request;
	}
	
	function trim_excerpt_without_filters($text)
	{
		$text = str_replace(']]>', ']]&gt;', $text);
		$text = preg_replace( '|\[(.+?)\](.+?\[/\\1\])?|s', '', $text);
		$text = strip_tags($text);
		
		$max = $this->maximum_description_length;
		
		if ($max < strlen($text))
		{
			while ($text[$max] != ' ' && $max > $this->minimum_description_length)
			{
				$max--;
			}
		}
		
		$text = substr($text, 0, $max);
		
		return trim(stripcslashes($text));
	}
	
	function trim_excerpt_without_filters_full_length($text)
	{
		$text = str_replace(']]>', ']]&gt;', $text);
		$text = preg_replace( '|\[(.+?)\](.+?\[/\\1\])?|s', '', $text);
		$text = strip_tags($text);

		return trim(stripcslashes($text));
	}
	
	/**
	 * @return comma-separated list of unique keywords
	 */
	function get_all_keywords()
	{
		global $posts;
		global $lightseop_options;

		if (is_404())
		{
			return null;
		}
		
		// if we are on synthetic pages
		if (!is_home() && !is_page() && !is_single() &&!$this->is_static_front_page() && !$this->is_static_posts_page()) 
		{
			return null;
		}

		$keywords = array();
		
		if (is_array($posts))
		{
			foreach ($posts as $post)
			{
				if ($post)
				{
					// custom field keywords
					$keywords_a = $keywords_i = null;
					$description_a = $description_i = null;
           
					$id = (is_attachment())?($post->post_parent):($post->ID); // if attachment then use parent post id
					$keywords_i = stripcslashes($this->internationalize(get_post_meta($id, "_lightseop_keywords", true)));
					//$id = $post->ID;
					//$keywords_i = stripcslashes($this->internationalize(get_post_meta($post->ID, "_lightseop_keywords", true)));
					$keywords_i = str_replace('"', '', $keywords_i);
	                
					if (isset($keywords_i) && !empty($keywords_i))
					{
						$traverse = explode(',', $keywords_i);
	                	
						foreach ($traverse as $keyword) 
						{
							$keywords[] = $keyword;
						}
					}
	                
					// WP 2.3 tags
					if ($lightseop_options['lightseo_use_tags_as_keywords'])
					{
						if (function_exists('get_the_tags'))
						{
							//$tags = get_the_tags($post->ID);
							$tags = get_the_tags($id);
							if ($tags && is_array($tags))
							{
								foreach ($tags as $tag)
								{
									$keywords[] = $this->internationalize($tag->name);
								}
							}
						}
					}

					// autometa
					$autometa = stripcslashes(get_post_meta($id, 'autometa', true));
					//$autometa = stripcslashes(get_post_meta($post->ID, "autometa", true));

					if (isset($autometa) && !empty($autometa))
					{
						$autometa_array = explode(' ', $autometa);
						
						foreach ($autometa_array as $e) 
						{
							$keywords[] = $e;
						}
					}

					if ($lightseop_options['lightseo_use_categories'] && !is_page())
					{
						$categories = get_the_category($id); 
						//$categories = get_the_category($post->ID);

						foreach ($categories as $category)
						{
							$keywords[] = $this->internationalize($category->cat_name);
						}
					}
				}
			}
		}
	    
		return $this->get_unique_keywords($keywords);
	}
	
	function get_meta_keywords()
	{
		global $posts;

		$keywords = array();
		
		if (is_array($posts))
		{
			foreach ($posts as $post)
			{
				if ($post)
				{
					// custom field keywords
					$keywords_a = $keywords_i = null;
					$description_a = $description_i = null;
					$id = $post->ID;
					$keywords_i = stripcslashes(get_post_meta($post->ID, "_lightseop_keywords", true));
					$keywords_i = str_replace('"', '', $keywords_i);

					if (isset($keywords_i) && !empty($keywords_i))
					{
						$keywords[] = $keywords_i;
					}
				}
			}
		}
	    
		return $this->get_unique_keywords($keywords);
	}
	
	function get_unique_keywords($keywords)
	{
		$small_keywords = array();
		
		foreach ($keywords as $word)
		{
			if (function_exists('mb_strtolower'))			
				$small_keywords[] = mb_strtolower($word, get_bloginfo('charset'));
			else 
				$small_keywords[] = $this->strtolower($word);
		}
		
		$keywords_ar = array_unique($small_keywords);
		
		return implode(',', $keywords_ar);
	}
	
	function get_url($url)
	{
		if (function_exists('file_get_contents'))
		{
			$file = file_get_contents($url);
		}
		else
		{
			$curl = curl_init($url);
			curl_setopt($curl, CURLOPT_HEADER, 0);
			curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
			$file = curl_exec($curl);
			curl_close($curl);
		}
		
		return $file;
	}
	
	function log($message)
	{
		if ($this->do_log)
		{
			error_log(date('Y-m-d H:i:s') . " " . $message . "\n", 3, $this->log_file);
		}
	}
	
	/** crude approximization of whether current user is an admin */
	function is_admin()
	{
		return current_user_can('level_8');
	}

	function post_meta_tags($id)
	{
		$awmp_edit = $_POST["lightseo_edit"];
		$nonce = $_POST['nonce-lightseop-edit'];
		
//		if (!wp_verify_nonce($nonce, 'edit-lightseop-nonce')) die ( 'Security Check - If you receive this in error, log out and back in to WordPress');
		if (isset($awmp_edit) && !empty($awmp_edit) && wp_verify_nonce($nonce, 'edit-lightseop-nonce'))
		{
			$keywords = $_POST["lightseo_keywords"];
			$description = $_POST["lightseo_description"];
			$title = $_POST["lightseo_title"];
			$lightseo_meta = $_POST["lightseo_meta"];
			$lightseo_disable = $_POST["lightseo_disable"];
			$lightseo_titleatr = $_POST["lightseo_titleatr"];
			$lightseo_menulabel = $_POST["lightseo_menulabel"];
				
			delete_post_meta($id, '_lightseop_keywords');
			delete_post_meta($id, '_lightseop_description');
			delete_post_meta($id, '_lightseop_title');
			delete_post_meta($id, '_lightseop_titleatr');
			delete_post_meta($id, '_lightseop_menulabel');
		
			if ($this->is_admin())
			{
				delete_post_meta($id, '_lightseop_disable');
			}
			//delete_post_meta($id, 'lightseo_meta');

			if (isset($keywords) && !empty($keywords))
			{
				add_post_meta($id, '_lightseop_keywords', $keywords);
			}

			if (isset($description) && !empty($description))
			{
				add_post_meta($id, '_lightseop_description', $description);
			}

			if (isset($title) && !empty($title))
			{
				add_post_meta($id, '_lightseop_title', $title);
			}
		    
			if (isset($lightseo_titleatr) && !empty($lightseo_titleatr))
			{
				add_post_meta($id, '_lightseop_titleatr', $lightseo_titleatr);
			}

			if (isset($lightseo_menulabel) && !empty($lightseo_menulabel))
			{
				add_post_meta($id, '_lightseop_menulabel', $lightseo_menulabel);
			}				

			if (isset($lightseo_disable) && !empty($lightseo_disable) && $this->is_admin())
			{
				add_post_meta($id, '_lightseop_disable', $lightseo_disable);
			}

			/*
			if (isset($lightseo_meta) && !empty($lightseo_meta))
			{
				add_post_meta($id, 'lightseo_meta', $lightseo_meta);
			}
			*/
		}
	}

	function edit_category($id)
	{
		global $wpdb;

		$id = $wpdb->escape($id);
		$awmp_edit = $_POST["lightseo_edit"];

		if (isset($awmp_edit) && !empty($awmp_edit))
		{
			$keywords = $wpdb->escape($_POST["lightseo_keywords"]);
			$title = $wpdb->escape($_POST["lightseo_title"]);
			$old_category = $wpdb->get_row("select * from $this->table_categories where category_id=$id", OBJECT);

			if ($old_category)
			{
				$wpdb->query($wpdb->prepare("update $this->table_categories
		    			set meta_title='$title', meta_keywords='$keywords'
		    			where category_id=$id"));
			}
			else
			{
				$wpdb->query($wpdb->prepare("insert into $this->table_categories(meta_title, meta_keywords, category_id)
		    			values ('$title', '$keywords', $id"));
			}
			
		    //$wpdb->query($wpdb->prepare("insert into $this->table_categories"))
	    	/*
		    delete_post_meta($id, 'keywords');
		    delete_post_meta($id, 'description');
		    delete_post_meta($id, 'title');

		    if (isset($keywords) && !empty($keywords)) {
			    add_post_meta($id, 'keywords', $keywords);
		    }
		    if (isset($description) && !empty($description)) {
			    add_post_meta($id, 'description', $description);
		    }
		    if (isset($title) && !empty($title)) {
			    add_post_meta($id, 'title', $title);
		    }
		    */
		}
	}

	function add_meta_tags_textinput()
	{
		global $post;
		
		$post_id = $post;
	    
		if (is_object($post_id))
		{
			$post_id = $post_id->ID;
		}

		$keywords = htmlspecialchars(stripcslashes(get_post_meta($post_id, '_lightseop_keywords', true)));
		$title = htmlspecialchars(stripcslashes(get_post_meta($post_id, '_lightseop_title', true)));
		$description = htmlspecialchars(stripcslashes(get_post_meta($post_id, '_lightseop_description', true)));
		$lightseo_meta = htmlspecialchars(stripcslashes(get_post_meta($post_id, '_lightseop_meta', true)));
		$lightseo_disable = htmlspecialchars(stripcslashes(get_post_meta($post_id, '_lightseop_disable', true)));
		$lightseo_titleatr = htmlspecialchars(stripcslashes(get_post_meta($post_id, '_lightseop_titleatr', true)));
		$lightseo_menulabel = htmlspecialchars(stripcslashes(get_post_meta($post_id, '_lightseop_menulabel', true)));		
	
?>
<script type="text/javascript">
function countChars(field,cntfield)
{
  cntfield.value = field.value.length;
}
</script>
<div id="postlightseo" class="postbox closed">
  <h3>
    <?php _e('Light SEO', 'light_seo') ?>
  </h3>
  <div class="inside">
    <div id="postlightseo">
      <input value="lightseo_edit" type="hidden" name="lightseo_edit" />
      <input type="hidden" name="nonce-lightseop-edit" value="<?php echo wp_create_nonce('edit-lightseop-nonce'); ?>" />
      <table style="margin-bottom:40px">
        <tr>
          <th style="text-align:left;" colspan="2">
          </th>
        </tr>
        <tr>
          <th scope="row" style="text-align:right;">
            <?php _e('Title:', 'light_seo') ?>
          </th>
          <td>
            <input value="<?php echo $title ?>" type="text" name="lightseo_title" size="62"/>
          </td>
        </tr>
        <tr>
          <th scope="row" style="text-align:right;">
            <?php _e('Description:', 'light_seo') ?>
          </th>
          <td>
            <textarea name="lightseo_description" rows="1" cols="60"
                onkeydown="countChars(document.post.lightseo_description,document.post.length1)"
                onkeyup="countChars(document.post.lightseo_description,document.post.length1)"><?php echo $description ?></textarea><br />
            <input readonly="" type="text" name="length1" size="3" maxlength="3" value="<?php echo strlen($description);?>" />
            <?php _e(' characters. Most search engines use a maximum of 160 chars for the description.', 'light_seo') ?>
          </td>
        </tr>
        <tr>
          <th scope="row" style="text-align:right;">
            <?php _e('Keywords (comma separated):', 'light_seo') ?>
          </th>
          <td>
            <input value="<?php echo $keywords ?>" type="text" name="lightseo_keywords" size="62" />
          </td>
        </tr>
<?php if ($this->is_admin()) { ?>
        <tr>
          <th scope="row" style="text-align:right; vertical-align:top;">
            <?php _e('Disable on this page/post:', 'light_seo')?>
          </th>
          <td>
            <input type="checkbox" name="lightseo_disable" <?php if ($lightseo_disable) echo 'checked="checked"'; ?> />
          </td>
        </tr>
        <tr>
          <th scope="row" style="text-align:right;">
            <?php _e('Title Attribute:', 'light_seo') ?>
          </th>
          <td>
            <input value="<?php echo $lightseo_titleatr ?>" type="text" name="lightseo_titleatr" size="62" />
          </td>
        </tr>
        <tr>
          <th scope="row" style="text-align:right;">
            <?php _e('Menu Label:', 'light_seo') ?>
          </th>
          <td>
            <input value="<?php echo $lightseo_menulabel ?>" type="text" name="lightseo_menulabel" size="62" />
          </td>
        </tr>
<?php } ?>
      </table>
    </div>
  </div>
</div>
<?php
	}

	/**
	 * Defines the sub-menu admin page using the add_submenu_page function.
	 */
	function admin_menu()
	{
		add_submenu_page('options-general.php', __('Light SEO', 'lightseo'), __('Light SEO', 'lightseo'), 'administrator', __FILE__, array($this, 'options_panel'));
	}
	
	function management_panel()
	{
		$message = null;
		$base_url = "edit.php?page=" . __FILE__;
		$type = $_REQUEST['type'];
		
		if (!isset($type))
		{
			$type = "posts";
		}
?>
  <ul class="lightseo_menu">
    <li>
      <a href="<?php echo $base_url ?>&type=posts">Posts</a>
    </li>
    <li>
      <a href="<?php echo $base_url ?>&type=pages">Pages</a>
    </li>
  </ul>
<?php
		if ($type == "posts") {
			echo("posts");
		} elseif ($type == "pages")
		{
			echo("pages");
		}
	}

	function options_panel()
	{
		$message = null;

		global $lightseop_options;		
		
		if(!$lightseop_options['lightseo_cap_cats'])
		{
			$lightseop_options['lightseo_cap_cats'] = '1';
		}
		
		if ($_POST['action'] && $_POST['action'] == 'lightseo_update' && $_POST['Submit_Default']!='')
		{
			$nonce = $_POST['nonce-lightseop'];
			
			if (!wp_verify_nonce($nonce, 'lightseop-nonce'))
				die ( 'Security Check - If you receive this in error, log out and back in to WordPress');
			
			$message = __("Light SEO Options Reset.", 'lightseo');

			delete_option('lightseop_options');

			$res_lightseop_options = array(
				"lightseo_can"=>1,
				"lightseo_home_title"=>null,
				"lightseo_home_description"=>'',
				"lightseo_home_keywords"=>null,
				"lightseo_max_words_excerpt"=>'something',
				"lightseo_rewrite_titles"=>1,
				"lightseo_post_title_format"=>'%post_title% | %blog_title%',
				"lightseo_page_title_format"=>'%page_title% | %blog_title%',
				"lightseo_category_title_format"=>'%category_title% | %blog_title%',
				"lightseo_archive_title_format"=>'%date% | %blog_title%',
				"lightseo_tag_title_format"=>'%tag% | %blog_title%',
				"lightseo_search_title_format"=>'%search% | %blog_title%',
				"lightseo_description_format"=>'%description%',
				"lightseo_404_title_format"=>'Nothing found for %request_words%',
				"lightseo_paged_format"=>' - Part %page%',
				"lightseo_use_categories"=>0,
				"lightseo_dynamic_postspage_keywords"=>1,
				"lightseo_category_noindex"=>1,
				"lightseo_archive_noindex"=>1,
				"lightseo_tags_noindex"=>0,
				"lightseo_cap_cats"=>1,
				"lightseo_generate_descriptions"=>1,
				"lightseo_debug_info"=>null,
				"lightseo_post_meta_tags"=>'',
				"lightseo_page_meta_tags"=>'',
				"lightseo_home_meta_tags"=>'',
				"lightseo_enabled" =>0,
				"lightseo_use_tags_as_keywords" =>1,
				"lightseo_do_log"=>null);
				
			update_option('lightseop_options', $res_lightseop_options);
		}
		
		// update options
		if ($_POST['action'] && $_POST['action'] == 'lightseo_update' && $_POST['Submit']!='')
		{
			$nonce = $_POST['nonce-lightseop'];
		
			if (!wp_verify_nonce($nonce, 'lightseop-nonce'))
				die ( 'Security Check - If you receive this in error, log out and back in to WordPress');
				
			$message = __("Light SEO Options Updated.", 'lightseo');
			
			$lightseop_options['lightseo_can'] = $_POST['lightseo_can'];
			$lightseop_options['lightseo_home_title'] = $_POST['lightseo_home_title'];
			$lightseop_options['lightseo_home_description'] = $_POST['lightseo_home_description'];
			$lightseop_options['lightseo_home_keywords'] = $_POST['lightseo_home_keywords'];
			$lightseop_options['lightseo_max_words_excerpt'] = $_POST['lightseo_max_words_excerpt'];
			$lightseop_options['lightseo_rewrite_titles'] = $_POST['lightseo_rewrite_titles'];
			$lightseop_options['lightseo_post_title_format'] = $_POST['lightseo_post_title_format'];
			$lightseop_options['lightseo_page_title_format'] = $_POST['lightseo_page_title_format'];
			$lightseop_options['lightseo_category_title_format'] = $_POST['lightseo_category_title_format'];
			$lightseop_options['lightseo_archive_title_format'] = $_POST['lightseo_archive_title_format'];
			$lightseop_options['lightseo_tag_title_format'] = $_POST['lightseo_tag_title_format'];
			$lightseop_options['lightseo_search_title_format'] = $_POST['lightseo_search_title_format'];
			$lightseop_options['lightseo_description_format'] = $_POST['lightseo_description_format'];
			$lightseop_options['lightseo_404_title_format'] = $_POST['lightseo_404_title_format'];
			$lightseop_options['lightseo_paged_format'] = $_POST['lightseo_paged_format'];
			$lightseop_options['lightseo_use_categories'] = $_POST['lightseo_use_categories'];
			$lightseop_options['lightseo_dynamic_postspage_keywords'] = $_POST['lightseo_dynamic_postspage_keywords'];
			$lightseop_options['lightseo_category_noindex'] = $_POST['lightseo_category_noindex'];
			$lightseop_options['lightseo_archive_noindex'] = $_POST['lightseo_archive_noindex'];
			$lightseop_options['lightseo_tags_noindex'] = $_POST['lightseo_tags_noindex'];
			$lightseop_options['lightseo_generate_descriptions'] = $_POST['lightseo_generate_descriptions'];
			$lightseop_options['lightseo_cap_cats'] = $_POST['lightseo_cap_cats'];
			$lightseop_options['lightseo_debug_info'] = $_POST['lightseo_debug_info'];
			$lightseop_options['lightseo_post_meta_tags'] = $_POST['lightseo_post_meta_tags'];
			$lightseop_options['lightseo_page_meta_tags'] = $_POST['lightseo_page_meta_tags'];
			$lightseop_options['lightseo_home_meta_tags'] = $_POST['lightseo_home_meta_tags'];
			$lightseop_options['lightseo_ex_pages'] = $_POST['lightseo_ex_pages'];
			$lightseop_options['lightseo_do_log'] = $_POST['lightseo_do_log'];
			$lightseop_options['lightseo_enabled'] = $_POST['lightseo_enabled'];
			$lightseop_options['lightseo_use_tags_as_keywords'] = $_POST['lightseo_use_tags_as_keywords'];			
			
			update_option('lightseop_options', $lightseop_options);
			
			if (function_exists('wp_cache_flush'))
			{
				wp_cache_flush();
			}
		}
?>
<?php if ($message) : ?>
  <div id="message" class="updated fade">
    <p>
      <?php echo $message; ?>
    </p>
  </div>
<?php endif; ?>
  <div id="dropmessage" class="updated" style="display:none;"></div>
  <div class="wrap">
    <h2>
      <?php _e('Light SEO Plugin Options', 'lightseo'); ?>
    </h2> by <a href="http://www.aldentorres.com/"><strong>Alden Torres</strong></a>
    <div style="clear:both;"></div>
<script type="text/javascript">
function toggleVisibility(id)
{
  var e = document.getElementById(id);

  if(e.style.display == 'block')
    e.style.display = 'none';
  else
    e.style.display = 'block';
}
</script>
    <br />
    <em><?php _e('Click on option titles to get help!', 'light_seo') ?></em>
<?php
		global $wpdb;

		$somecount = $wpdb->get_var("SELECT COUNT(*) FROM $wpdb->postmeta WHERE meta_key = 'keywords'");
		$somecount = $wpdb->get_var("SELECT COUNT(*) FROM $wpdb->postmeta WHERE meta_key = 'title'") + $somecount;
		$somecount = $wpdb->get_var("SELECT COUNT(*) FROM $wpdb->postmeta WHERE meta_key = 'description'") + $somecount;
		$somecount = $wpdb->get_var("SELECT COUNT(*) FROM $wpdb->postmeta WHERE meta_key = 'lightseo_meta'") + $somecount;
		$somecount = $wpdb->get_var("SELECT COUNT(*) FROM $wpdb->postmeta WHERE meta_key = 'lightseo_disable'") + $somecount;
	
		if ($somecount > 0)
		{
			echo "<div class='error' style='text-align:center;'><p><strong>Your database meta needs to be updated.  " . $somecount . " old fields remaining</strong> <em>(Back up your database before updating.)</em>
					<FORM action='' method='post' name='lightseop-migrate'>
					<input type='hidden' name='nonce-lightseop-migrate' value='" . wp_create_nonce('lightseop-migrate-nonce') . "' />
					<input type='submit' name='lightseop_migrate' class='button-primary' value='Update Database'>
				</FORM>
				</p></div>";
		}

		if (!get_option('lightseop_options'))
		{
			echo "<div class='error' style='text-align:center;'><p><strong>Your database options need to be updated.</strong><em>(Back up your database before updating.)</em>
				<FORM action='' method='post' name='lightseop-migrate-options'>
				<input type='hidden' name='nonce-lightseop-migrate-options' value='" . wp_create_nonce('lightseop-migrate-nonce-options') . "' />
				<input type='submit' name='lightseop_migrate_options' class='button-primary' value='Update Database Options'>
				</FORM>
				</p></div>";
		}
?>
    <form name="dofollow" action="" method="post">
      <table class="form-table">
        <?php $lightseop_options = get_option('lightseop_options'); ?>
        <tr>
          <th scope="row" style="text-align:right; vertical-align:top;">
            <a style="cursor:pointer;" title="<?php _e('Click for Help!', 'light_seo')?>" onclick="toggleVisibility('lightseo_enabled_tip');">
              <?php _e('Plugin Status:', 'light_seo')?>
            </a>
          </th>
          <td>
            <input type="radio" name="lightseo_enabled" value="1" <?php if($lightseop_options['lightseo_enabled']) echo 'checked="checked"'?> /> Enabled<br />
            <input type="radio" name="lightseo_enabled" value="0" <?php if(!$lightseop_options['lightseo_enabled']) echo 'checked="checked"'?> /> Disabled
            <div style="max-width:500px; text-align:left; display:none" id="lightseo_enabled_tip">
              <?php _e('Light SEO must be enabled for use.', 'light_seo')?>
            </div>
          </td>
        </tr>
        <tr>
          <th scope="row" style="text-align:right; vertical-align:top;">
            <a style="cursor:pointer;" title="<?php _e('Click for Help!', 'light_seo')?>" onclick="toggleVisibility('lightseo_home_title_tip');">
              <?php _e('Home Title:', 'light_seo')?>
            </a>
          </th>
          <td>
            <textarea cols="57" rows="2" name="lightseo_home_title"><?php echo stripcslashes($lightseop_options['lightseo_home_title'])?></textarea>
            <div style="max-width:500px; text-align:left; display:none" id="lightseo_home_title_tip">
              <?php _e('As the name implies, this will be the title of your homepage. This is independent of any other option. If not set, the default blog title will get used.', 'light_seo')?>
            </div>
          </td>
        </tr>
        <tr>
          <th scope="row" style="text-align:right; vertical-align:top;">
            <a style="cursor:pointer;" title="<?php _e('Click for Help!', 'light_seo')?>" onclick="toggleVisibility('lightseo_home_description_tip');">
              <?php _e('Home Description:', 'light_seo')?>
            </a>
          </th>
          <td>
            <textarea cols="57" rows="2" name="lightseo_home_description"><?php echo stripcslashes($lightseop_options['lightseo_home_description'])?></textarea>
            <div style="max-width:500px; text-align:left; display:none" id="lightseo_home_description_tip">
              <?php _e('The META description for your homepage. Independent of any other options, the default is no META description at all if this is not set.', 'light_seo')?>
            </div>
          </td>
        </tr>
        <tr>
          <th scope="row" style="text-align:right; vertical-align:top;">
            <a style="cursor:pointer;" title="<?php _e('Click for Help!', 'light_seo')?>" onclick="toggleVisibility('lightseo_home_keywords_tip');">
              <?php _e('Home Keywords (comma separated):', 'light_seo')?>
            </a>
          </th>
          <td>
            <textarea cols="57" rows="2" name="lightseo_home_keywords"><?php echo stripcslashes($lightseop_options['lightseo_home_keywords']); ?></textarea>
            <div style="max-width:500px; text-align:left; display:none" id="lightseo_home_keywords_tip">
              <?php _e("A comma separated list of your most important keywords for your site that will be written as META keywords on your homepage. Don't stuff everything in here.", 'light_seo')?>
            </div>
          </td>
        </tr>
        <tr>
          <th scope="row" style="text-align:right; vertical-align:top;">
            <a style="cursor:pointer;" title="<?php _e('Click for Help!', 'light_seo')?>" onclick="toggleVisibility('lightseo_can_tip');">
              <?php _e('Canonical URLs:', 'light_seo')?>
            </a>
          </th>
          <td>
            <input type="checkbox" name="lightseo_can" <?php if ($lightseop_options['lightseo_can']) echo 'checked="checked"'; ?>/>
            <div style="max-width:500px; text-align:left; display:none" id="lightseo_can_tip">
              <?php _e("This option will automatically generate Canonical URLS for your entire WordPress installation.  This will help to prevent duplicate content penalties by <a href='http://googlewebmastercentral.blogspot.com/2009/02/specify-your-canonical.html' target='_blank'>Google</a>.", 'light_seo')?>
            </div>
          </td>
        </tr>
        <tr>
          <th scope="row" style="text-align:right; vertical-align:top;">
            <a style="cursor:pointer;" title="<?php _e('Click for Help!', 'light_seo')?>" onclick="toggleVisibility('lightseo_rewrite_titles_tip');">
              <?php _e('Rewrite Titles:', 'light_seo')?>
            </a>
          </th>
          <td>
            <input type="checkbox" name="lightseo_rewrite_titles" <?php if ($lightseop_options['lightseo_rewrite_titles']) echo 'checked="checked"'; ?>/>
            <div style="max-width:500px; text-align:left; display:none" id="lightseo_rewrite_titles_tip">
              <?php _e("Note that this is all about the title tag. This is what you see in your browser's window title bar. This is NOT visible on a page, only in the window title bar and of course in the source. If set, all page, post, category, search and archive page titles get rewritten. You can specify the format for most of them. For example: The default templates puts the title tag of posts like this: Blog Archive >> Blog Name >> Post Title (maybe I've overdone slightly). This is far from optimal. With the default post title format, Rewrite Title rewrites this to Post Title | Blog Name. If you have manually defined a title (in one of the text fields for All in One SEO Plugin input) this will become the title of your post in the format string.", 'light_seo')?>
            </div>
          </td>
        </tr>
        <tr>
          <th scope="row" style="text-align:right; vertical-align:top;">
            <a style="cursor:pointer;" title="<?php _e('Click for Help!', 'light_seo')?>" onclick="toggleVisibility('lightseo_post_title_format_tip');">
              <?php _e('Post Title Format:', 'light_seo')?>
            </a>
          </th>
          <td>
            <input size="59" name="lightseo_post_title_format" value="<?php echo stripcslashes($lightseop_options['lightseo_post_title_format']); ?>"/>
            <div style="max-width:500px; text-align:left; display:none" id="lightseo_post_title_format_tip">
<?php
_e('The following macros are supported:', 'light_seo');
echo('<ul>');
echo('<li>'); _e('%blog_title% - Your blog title', 'light_seo'); echo('</li>');
echo('<li>'); _e('%blog_description% - Your blog description', 'light_seo'); echo('</li>');
echo('<li>'); _e('%post_title% - The original title of the post', 'light_seo'); echo('</li>');
echo('<li>'); _e('%category_title% - The (main) category of the post', 'light_seo'); echo('</li>');
echo('<li>'); _e('%category% - Alias for %category_title%', 'light_seo'); echo('</li>');
echo('<li>'); _e("%post_author_login% - This post's author' login", 'light_seo'); echo('</li>');
echo('<li>'); _e("%post_author_nicename% - This post's author' nicename", 'light_seo'); echo('</li>');
echo('<li>'); _e("%post_author_firstname% - This post's author' first name (capitalized)", 'light_seo'); echo('</li>');
echo('<li>'); _e("%post_author_lastname% - This post's author' last name (capitalized)", 'light_seo'); echo('</li>');
echo('</ul>');
?>
            </div>
          </td>
        </tr>
        <tr>
          <th scope="row" style="text-align:right; vertical-align:top;">
            <a style="cursor:pointer;" title="<?php _e('Click for Help!', 'light_seo')?>" onclick="toggleVisibility('lightseo_page_title_format_tip');">
              <?php _e('Page Title Format:', 'light_seo')?>
            </a>
          </th>
          <td>
            <input size="59" name="lightseo_page_title_format" value="<?php echo stripcslashes($lightseop_options['lightseo_page_title_format']); ?>"/>
            <div style="max-width:500px; text-align:left; display:none" id="lightseo_page_title_format_tip">
<?php
_e('The following macros are supported:', 'light_seo');
echo('<ul>');
echo('<li>'); _e('%blog_title% - Your blog title', 'light_seo'); echo('</li>');
echo('<li>'); _e('%blog_description% - Your blog description', 'light_seo'); echo('</li>');
echo('<li>'); _e('%page_title% - The original title of the page', 'light_seo'); echo('</li>');
echo('<li>'); _e("%page_author_login% - This page's author' login", 'light_seo'); echo('</li>');
echo('<li>'); _e("%page_author_nicename% - This page's author' nicename", 'light_seo'); echo('</li>');
echo('<li>'); _e("%page_author_firstname% - This page's author' first name (capitalized)", 'light_seo'); echo('</li>');
echo('<li>'); _e("%page_author_lastname% - This page's author' last name (capitalized)", 'light_seo'); echo('</li>');
echo('</ul>');
?>
            </div>
          </td>
        </tr>
        <tr>
          <th scope="row" style="text-align:right; vertical-align:top;">
            <a style="cursor:pointer;" title="<?php _e('Click for Help!', 'light_seo')?>" onclick="toggleVisibility('lightseo_category_title_format_tip');">
              <?php _e('Category Title Format:', 'light_seo')?>
            </a>
          </th>
          <td>
            <input size="59" name="lightseo_category_title_format" value="<?php echo stripcslashes($lightseop_options['lightseo_category_title_format']); ?>"/>
            <div style="max-width:500px; text-align:left; display:none" id="lightseo_category_title_format_tip">
<?php
_e('The following macros are supported:', 'light_seo');
echo('<ul>');
echo('<li>'); _e('%blog_title% - Your blog title', 'light_seo'); echo('</li>');
echo('<li>'); _e('%blog_description% - Your blog description', 'light_seo'); echo('</li>');
echo('<li>'); _e('%category_title% - The original title of the category', 'light_seo'); echo('</li>');
echo('<li>'); _e('%category_description% - The description of the category', 'light_seo'); echo('</li>');
echo('</ul>');
?>
            </div>
          </td>
        </tr>
        <tr>
          <th scope="row" style="text-align:right; vertical-align:top;">
            <a style="cursor:pointer;" title="<?php _e('Click for Help!', 'light_seo')?>" onclick="toggleVisibility('lightseo_archive_title_format_tip');">
              <?php _e('Archive Title Format:', 'light_seo')?>
            </a>
          </th>
          <td>
            <input size="59" name="lightseo_archive_title_format" value="<?php echo stripcslashes($lightseop_options['lightseo_archive_title_format']); ?>"/>
            <div style="max-width:500px; text-align:left; display:none" id="lightseo_archive_title_format_tip">
<?php
_e('The following macros are supported:', 'light_seo');
echo('<ul>');
echo('<li>'); _e('%blog_title% - Your blog title', 'light_seo'); echo('</li>');
echo('<li>'); _e('%blog_description% - Your blog description', 'light_seo'); echo('</li>');
echo('<li>'); _e('%date% - The original archive title given by wordpress, e.g. "2007" or "2007 August"', 'light_seo'); echo('</li>');
echo('</ul>');
?>
            </div>
          </td>
        </tr>
        <tr>
          <th scope="row" style="text-align:right; vertical-align:top;">
            <a style="cursor:pointer;" title="<?php _e('Click for Help!', 'light_seo')?>" onclick="toggleVisibility('lightseo_tag_title_format_tip');">
              <?php _e('Tag Title Format:', 'light_seo')?>
            </a>
          </th>
          <td>
            <input size="59" name="lightseo_tag_title_format" value="<?php echo stripcslashes($lightseop_options['lightseo_tag_title_format']); ?>"/>
            <div style="max-width:500px; text-align:left; display:none" id="lightseo_tag_title_format_tip">
<?php
_e('The following macros are supported:', 'light_seo');
echo('<ul>');
echo('<li>'); _e('%blog_title% - Your blog title', 'light_seo'); echo('</li>');
echo('<li>'); _e('%blog_description% - Your blog description', 'light_seo'); echo('</li>');
echo('<li>'); _e('%tag% - The name of the tag', 'light_seo'); echo('</li>');
echo('</ul>');
?>
            </div>
          </td>
        </tr>
        <tr>
          <th scope="row" style="text-align:right; vertical-align:top;">
            <a style="cursor:pointer;" title="<?php _e('Click for Help!', 'light_seo')?>" onclick="toggleVisibility('lightseo_search_title_format_tip');">
              <?php _e('Search Title Format:', 'light_seo')?>
            </a>
          </th>
          <td>
            <input size="59" name="lightseo_search_title_format" value="<?php echo stripcslashes($lightseop_options['lightseo_search_title_format']); ?>"/>
            <div style="max-width:500px; text-align:left; display:none" id="lightseo_search_title_format_tip">
<?php
_e('The following macros are supported:', 'light_seo');
echo('<ul>');
echo('<li>'); _e('%blog_title% - Your blog title', 'light_seo'); echo('</li>');
echo('<li>'); _e('%blog_description% - Your blog description', 'light_seo'); echo('</li>');
echo('<li>'); _e('%search% - What was searched for', 'light_seo'); echo('</li>');
echo('</ul>');
?>
            </div>
          </td>
        </tr>
        <tr>
          <th scope="row" style="text-align:right; vertical-align:top;">
            <a style="cursor:pointer;" title="<?php _e('Click for Help!', 'light_seo')?>" onclick="toggleVisibility('lightseo_description_format_tip');">
              <?php _e('Description Format:', 'light_seo')?>
            </a>
          </th>
          <td>
            <input size="59" name="lightseo_description_format" value="<?php echo stripcslashes($lightseop_options['lightseo_description_format']); ?>"/>
            <div style="max-width:500px; text-align:left; display:none" id="lightseo_description_format_tip">
<?php
_e('The following macros are supported:', 'light_seo');
echo('<ul>');
echo('<li>'); _e('%blog_title% - Your blog title', 'light_seo'); echo('</li>');
echo('<li>'); _e('%blog_description% - Your blog description', 'light_seo'); echo('</li>');
echo('<li>'); _e('%description% - The original description as determined by the plugin, e.g. the excerpt if one is set or an auto-generated one if that option is set', 'light_seo'); echo('</li>');
echo('<li>'); _e('%wp_title% - The original wordpress title, e.g. post_title for posts', 'light_seo'); echo('</li>');
echo('</ul>');
?>
            </div>
          </td>
        </tr>
        <tr>
          <th scope="row" style="text-align:right; vertical-align:top;">
            <a style="cursor:pointer;" title="<?php _e('Click for Help!', 'light_seo')?>" onclick="toggleVisibility('lightseo_404_title_format_tip');">
              <?php _e('404 Title Format:', 'light_seo')?>
            </a>
          </th>
          <td>
            <input size="59" name="lightseo_404_title_format" value="<?php echo stripcslashes($lightseop_options['lightseo_404_title_format']); ?>"/>
            <div style="max-width:500px; text-align:left; display:none" id="lightseo_404_title_format_tip">
<?php
_e('The following macros are supported:', 'light_seo');
echo('<ul>');
echo('<li>'); _e('%blog_title% - Your blog title', 'light_seo'); echo('</li>');
echo('<li>'); _e('%blog_description% - Your blog description', 'light_seo'); echo('</li>');
echo('<li>'); _e('%request_url% - The original URL path, like "/url-that-does-not-exist/"', 'light_seo'); echo('</li>');
echo('<li>'); _e('%request_words% - The URL path in human readable form, like "Url That Does Not Exist"', 'light_seo'); echo('</li>');
echo('<li>'); _e('%404_title% - Additional 404 title input"', 'light_seo'); echo('</li>');
echo('</ul>');
?>
            </div>
          </td>
        </tr>
        <tr>
          <th scope="row" style="text-align:right; vertical-align:top;">
            <a style="cursor:pointer;" title="<?php _e('Click for Help!', 'light_seo')?>" onclick="toggleVisibility('lightseo_paged_format_tip');">
              <?php _e('Paged Format:', 'light_seo')?>
            </a>
          </th>
          <td>
            <input size="59" name="lightseo_paged_format" value="<?php echo stripcslashes($lightseop_options['lightseo_paged_format']); ?>"/>
            <div style="max-width:500px; text-align:left; display:none" id="lightseo_paged_format_tip">
<?php
_e('This string gets appended/prepended to titles when they are for paged index pages (like home or archive pages).', 'light_seo');
_e('The following macros are supported:', 'light_seo');
echo('<ul>');
echo('<li>'); _e('%page% - The page number', 'light_seo'); echo('</li>');
echo('</ul>');
?>
            </div>
          </td>
        </tr>
        <tr>
          <th scope="row" style="text-align:right; vertical-align:top;">
            <a style="cursor:pointer;" title="<?php _e('Click for Help!', 'light_seo')?>" onclick="toggleVisibility('lightseo_use_categories_tip');">
              <?php _e('Use Categories for META keywords:', 'light_seo')?>
            </a>
          </th>
          <td>
            <input type="checkbox" name="lightseo_use_categories" <?php if ($lightseop_options['lightseo_use_categories']) echo 'checked="checked"'; ?>/>
            <div style="max-width:500px; text-align:left; display:none" id="lightseo_use_categories_tip">
              <?php _e('Check this if you want your categories for a given post used as the META keywords for this post (in addition to any keywords and tags you specify on the post edit page).', 'light_seo')?>
            </div>
          </td>
        </tr>
        <tr>
          <th scope="row" style="text-align:right; vertical-align:top;">
            <a style="cursor:pointer;" title="<?php _e('Click for Help!', 'light_seo')?>" onclick="toggleVisibility('lightseo_use_tags_as_keywords_tip');">
              <?php _e('Use Tags for META keywords:', 'light_seo')?>
            </a>
          </th>
          <td>
            <input type="checkbox" name="lightseo_use_tags_as_keywords" <?php if ($lightseop_options['lightseo_use_tags_as_keywords']) echo 'checked="checked"'; ?>/>
            <div style="max-width:500px; text-align:left; display:none" id="lightseo_use_tags_as_keywords_tip">
              <?php _e('Check this if you want your tags for a given post used as the META keywords for this post (in addition to any keywords you specify on the post edit page).', 'light_seo')?>
            </div>
          </td>
        </tr>
        <tr>
          <th scope="row" style="text-align:right; vertical-align:top;">
            <a style="cursor:pointer;" title="<?php _e('Click for Help!', 'light_seo')?>" onclick="toggleVisibility('lightseo_dynamic_postspage_keywords_tip');">
              <?php _e('Dynamically Generate Keywords for Posts Page:', 'light_seo')?>
            </a>
          </th>
          <td>
            <input type="checkbox" name="lightseo_dynamic_postspage_keywords" <?php if ($lightseop_options['lightseo_dynamic_postspage_keywords']) echo 'checked="checked"'; ?>/>
            <div style="max-width:500px; text-align:left; display:none" id="lightseo_dynamic_postspage_keywords_tip">
              <?php _e('Check this if you want your keywords on a custom posts page (set it in options->reading) to be dynamically generated from the keywords of the posts showing on that page.  If unchecked, it will use the keywords set in the edit page screen for the posts page.', 'light_seo') ?>
            </div>
          </td>
        </tr>
        <tr>
          <th scope="row" style="text-align:right; vertical-align:top;">
            <a style="cursor:pointer;" title="<?php _e('Click for Help!', 'light_seo')?>" onclick="toggleVisibility('lightseo_category_noindex_tip');">
              <?php _e('Use noindex for Categories:', 'light_seo')?>
            </a>
          </th>
          <td>
            <input type="checkbox" name="lightseo_category_noindex" <?php if ($lightseop_options['lightseo_category_noindex']) echo 'checked="checked"'; ?>/>
            <div style="max-width:500px; text-align:left; display:none" id="lightseo_category_noindex_tip">
              <?php _e('Check this for excluding category pages from being crawled. Useful for avoiding duplicate content.', 'light_seo')?>
            </div>
          </td>
        </tr>
        <tr>
          <th scope="row" style="text-align:right; vertical-align:top;">
            <a style="cursor:pointer;" title="<?php _e('Click for Help!', 'light_seo')?>" onclick="toggleVisibility('lightseo_archive_noindex_tip');">
              <?php _e('Use noindex for Archives:', 'light_seo')?>
            </a>
          </th>
          <td>
            <input type="checkbox" name="lightseo_archive_noindex" <?php if ($lightseop_options['lightseo_archive_noindex']) echo 'checked="checked"'; ?>/>
            <div style="max-width:500px; text-align:left; display:none" id="lightseo_archive_noindex_tip">
              <?php _e('Check this for excluding archive pages from being crawled. Useful for avoiding duplicate content.', 'light_seo')?>
            </div>
          </td>
        </tr>
        <tr>
          <th scope="row" style="text-align:right; vertical-align:top;">
            <a style="cursor:pointer;" title="<?php _e('Click for Help!', 'light_seo')?>" onclick="toggleVisibility('lightseo_tags_noindex_tip');">
              <?php _e('Use noindex for Tag Archives:', 'light_seo')?>
            </a>
          </th>
          <td>
            <input type="checkbox" name="lightseo_tags_noindex" <?php if ($lightseop_options['lightseo_tags_noindex']) echo 'checked="checked"'; ?>/>
            <div style="max-width:500px; text-align:left; display:none" id="lightseo_tags_noindex_tip">
              <?php _e('Check this for excluding tag pages from being crawled. Useful for avoiding duplicate content.', 'light_seo')?>
            </div>
          </td>
        </tr>
        <tr>
          <th scope="row" style="text-align:right; vertical-align:top;">
            <a style="cursor:pointer;" title="<?php _e('Click for Help!', 'light_seo')?>" onclick="toggleVisibility('lightseo_generate_descriptions_tip');">
              <?php _e('Autogenerate Descriptions:', 'light_seo')?>
            </a>
          </th>
          <td>
            <input type="checkbox" name="lightseo_generate_descriptions" <?php if ($lightseop_options['lightseo_generate_descriptions']) echo 'checked="checked"'; ?>/>
            <div style="max-width:500px; text-align:left; display:none" id="lightseo_generate_descriptions_tip">
              <?php _e("Check this and your META descriptions will get autogenerated if there's no excerpt.", 'light_seo')?>
            </div>
          </td>
        </tr>
        <tr>
          <th scope="row" style="text-align:right; vertical-align:top;">
            <a style="cursor:pointer;" title="<?php _e('Click for Help!', 'light_seo')?>" onclick="toggleVisibility('lightseo_cap_cats_tip');">
              <?php _e('Capitalize Category Titles:', 'light_seo')?>
            </a>
          </th>
          <td>
            <input type="checkbox" name="lightseo_cap_cats" <?php if ($lightseop_options['lightseo_cap_cats']) echo 'checked="checked"'; ?>/>
            <div style="max-width:500px; text-align:left; display:none" id="lightseo_cap_cats_tip">
              <?php _e("Check this and Category Titles will have the first letter of each word capitalized.", 'light_seo')?>
            </div>
          </td>
        </tr>
        <tr>
          <th scope="row" style="text-align:right; vertical-align:top;">
            <a style="cursor:pointer;" title="<?php _e('Click for Help!', 'light_seo')?>" onclick="toggleVisibility('lightseo_ex_pages_tip');">
              <?php _e('Exclude Pages:', 'light_seo')?>
            </a>
          </th>
          <td>
            <textarea cols="57" rows="2" name="lightseo_ex_pages"><?php echo stripcslashes($lightseop_options['lightseo_ex_pages'])?></textarea>
            <div style="max-width:500px; text-align:left; display:none" id="lightseo_ex_pages_tip">
              <?php _e("Enter any comma separated pages here to be excluded by All in One SEO Pack.  This is helpful when using plugins which generate their own non-WordPress dynamic pages.  Ex: <em>/forum/,/contact/</em>  For instance, if you want to exclude the virtual pages generated by a forum plugin, all you have to do is give forum or /forum or /forum/ or and any URL with the word \"forum\" in it, such as http://mysite.com/forum or http://mysite.com/forum/someforumpage will be excluded from Light SEO.", 'light_seo')?>
            </div>
          </td>
        </tr>
        <tr>
          <th scope="row" style="text-align:right; vertical-align:top;">
            <a style="cursor:pointer;" title="<?php _e('Click for Help!', 'light_seo')?>" onclick="toggleVisibility('lightseo_post_meta_tags_tip');">
              <?php _e('Additional Post Headers:', 'light_seo')?>
            </a>
          </th>
          <td>
            <textarea cols="57" rows="2" name="lightseo_post_meta_tags"><?php echo stripcslashes($lightseop_options['lightseo_post_meta_tags'])?></textarea>
            <div style="max-width:500px; text-align:left; display:none" id="lightseo_post_meta_tags_tip">
              <?php _e('What you enter here will be copied verbatim to your header on post pages. You can enter whatever additional headers you want here, even references to stylesheets.', 'light_seo')?>
            </div>
          </td>
        </tr>
        <tr>
          <th scope="row" style="text-align:right; vertical-align:top;">
            <a style="cursor:pointer;" title="<?php _e('Click for Help!', 'light_seo')?>" onclick="toggleVisibility('lightseo_page_meta_tags_tip');">
              <?php _e('Additional Page Headers:', 'light_seo')?>
            </a>
          </th>
          <td>
            <textarea cols="57" rows="2" name="lightseo_page_meta_tags"><?php echo stripcslashes($lightseop_options['lightseo_page_meta_tags'])?></textarea>
            <div style="max-width:500px; text-align:left; display:none" id="lightseo_page_meta_tags_tip">
              <?php _e('What you enter here will be copied verbatim to your header on pages. You can enter whatever additional headers you want here, even references to stylesheets.', 'light_seo')?>
            </div>
          </td>
        </tr>
        <tr>
          <th scope="row" style="text-align:right; vertical-align:top;">
            <a style="cursor:pointer;" title="<?php _e('Click for Help!', 'light_seo')?>" onclick="toggleVisibility('lightseo_home_meta_tags_tip');">
              <?php _e('Additional Home Headers:', 'light_seo')?>
            </a>
          </th>
          <td>
            <textarea cols="57" rows="2" name="lightseo_home_meta_tags"><?php echo stripcslashes($lightseop_options['lightseo_home_meta_tags'])?></textarea>
            <div style="max-width:500px; text-align:left; display:none" id="lightseo_home_meta_tags_tip">
              <?php _e('What you enter here will be copied verbatim to your header on the home page. You can enter whatever additional headers you want here, even references to stylesheets.', 'light_seo')?>
            </div>
          </td>
        </tr>
        <tr>
          <th scope="row" style="text-align:right; vertical-align:top;">
            <a style="cursor:pointer;" title="<?php _e('Click for Help!', 'auto_social')?>" onclick="toggleVisibility('lightseo_do_log_tip');">
              <?php _e('Log important events:', 'light_seo')?>
            </a>
          </th>
          <td>
            <input type="checkbox" name="lightseo_do_log" <?php if ($lightseop_options['lightseo_do_log']) echo 'checked="checked"'; ?>/>
            <div style="max-width:500px; text-align:left; display:none" id="lightseo_do_log_tip">
              <?php _e('Check this and Light SEO will create a log of important events (light_seo.log) in its plugin directory which might help debugging it. Make sure this directory is writable.', 'light_seo')?>
            </div>
          </td>
        </tr>
      </table>
      <p class="submit">
        <?php if($lightseop_options) {  ?>
        <input type="hidden" name="action" value="lightseo_update" />
        <input type="hidden" name="nonce-lightseop" value="<?php echo wp_create_nonce('lightseop-nonce'); ?>" />
        <input type="hidden" name="page_options" value="lightseo_home_description" />
        <input type="submit" class='button-primary' name="Submit" value="<?php _e('Update Options', 'light_seo')?> &raquo;" />
        <input type="submit" class='button-primary' name="Submit_Default" value="<?php _e('Reset Settings to Defaults', 'light_seo')?> &raquo;" />
      </p>
      <?php } ?>
    </form>
  </div>
  <?php
	} // options_panel
} // end Light_SEO class

global $lightseop_options;
$lightseop_options = get_option('lightseop_options');

if($_POST['lightseop_migrate']) lightseop_mrt_fix_meta();
if($_POST['lightseop_migrate_options']) lightseop_mrt_mkarry();
if(!get_option('lightseo_post_title_format') && !get_option('lightseop_options')) lightseop_mrt_mkarry();

function lightseop_mrt_fix_meta()
{
	global $wpdb;

	$wpdb->query("UPDATE $wpdb->postmeta SET meta_key = '_lightseop_keywords' WHERE meta_key = 'keywords'");
	$wpdb->query("UPDATE $wpdb->postmeta SET meta_key = '_lightseop_title' WHERE meta_key = 'title'");	
	$wpdb->query("UPDATE $wpdb->postmeta SET meta_key = '_lightseop_description' WHERE meta_key = 'description'");
	$wpdb->query("UPDATE $wpdb->postmeta SET meta_key = '_lightseop_meta' WHERE meta_key = 'lightseo_meta'");
	$wpdb->query("UPDATE $wpdb->postmeta SET meta_key = '_lightseop_disable' WHERE meta_key = 'lightseo_disable'");

	echo "<div class='updated fade' style='background-color:green;border-color:green;'><p><strong>Updating SEO post meta in database.</strong></p></div";
}

function lightseop_mrt_mkarry()
{
	$nlightseop_options = array(
		"lightseo_can"=>1,
		"lightseo_home_title"=>null,
		"lightseo_home_description"=>'',
		"lightseo_home_keywords"=>null,
		"lightseo_max_words_excerpt"=>'something',
		"lightseo_rewrite_titles"=>1,
		"lightseo_post_title_format"=>'%post_title% | %blog_title%',
		"lightseo_page_title_format"=>'%page_title% | %blog_title%',
		"lightseo_category_title_format"=>'%category_title% | %blog_title%',
		"lightseo_archive_title_format"=>'%date% | %blog_title%',
		"lightseo_tag_title_format"=>'%tag% | %blog_title%',
		"lightseo_search_title_format"=>'%search% | %blog_title%',
		"lightseo_description_format"=>'%description%',
		"lightseo_404_title_format"=>'Nothing found for %request_words%',
		"lightseo_paged_format"=>' - Part %page%',
		"lightseo_use_categories"=>0,
		"lightseo_dynamic_postspage_keywords"=>1,
		"lightseo_category_noindex"=>1,
		"lightseo_archive_noindex"=>1,
		"lightseo_tags_noindex"=>0,
		"lightseo_cap_cats"=>1,
		"lightseo_generate_descriptions"=>1,
		"lightseo_debug_info"=>null,
		"lightseo_post_meta_tags"=>'',
		"lightseo_page_meta_tags"=>'',
		"lightseo_home_meta_tags"=>'',
		"lightseo_enabled" =>0,
		"lightseo_use_tags_as_keywords" =>1,
		"lightseo_do_log"=>null);

	if (get_option('lightseo_post_title_format'))
	{
		foreach ($nlightseop_options as $lightseop_opt_name => $value )
		{
			if ($lightseop_oldval = get_option($lightseop_opt_name))
			{
				$nlightseop_options[$lightseop_opt_name] = $lightseop_oldval;
			}
			
			if ($lightseop_oldval == '')
			{
				$nlightseop_options[$lightseop_opt_name] = '';
			}
        
			delete_option($lightseop_opt_name);
		}
	}

	add_option('lightseop_options',$nlightseop_options);
	
	echo "<div class='updated fade' style='background-color:green;border-color:green;'><p><strong>Updating SEO configuration options in database</strong></p></div>";
}

function lightseop_activation_notice()
{
	global $lightseop_options;

	if(function_exists('admin_url'))
	{
		echo '<div class="error fade" style="background-color:red;"><p><strong>Light SEO must be configured. Go to <a href="' . admin_url( 'options-general.php?page=light-seo/lightseo.php' ) . '">the admin page</a> to enable and configure the plugin.</strong><br />WordPress now has a canonical URL feature, however we recommend using the lightseop <em>advanced canonical URLs functionality</em> we have had for the past year.</p></div>';
	}
	else
	{
		echo '<div class="error fade" style="background-color:red;"><p><strong>All in One SEO Pack must be configured. Go to <a href="' . get_option('siteurl') . 'options-general.php?page=all-in-one-seo-pack/lightseop.class.php' . '">the admin page</a> to enable and configure the plugin.</strong></p></div>';
	}
}

function lightseop_list_pages($content)
{
	$url = preg_replace(array('/\//', '/\./', '/\-/'), array('\/', '\.', '\-'), get_option('siteurl'));
	$pattern = '/<li class="page_item page-item-(\d+)([^\"]*)"><a href=\"([^\"]+)" title="([^\"]+)">([^<]+)<\/a>/i';

	return preg_replace_callback($pattern, "lightseop_filter_callback", $content);
}

function lightseop_filter_callback($matches)
{
	global $wpdb;
	
	if ($matches[1] && !empty($matches[1]))
		$postID = $matches[1];
		
	if (empty($postID))
		$postID = get_option("page_on_front");
		
	$title_attrib = stripslashes(get_post_meta($postID, '_lightseop_titleatr', true));
	$menulabel = stripslashes(get_post_meta($postID, '_lightseop_menulabel', true));
	
	if (empty($menulabel))
		$menulabel = $matches[4];
		
	if (!empty($title_attrib)) :
		$filtered = '<li class="page_item page-item-'.$postID.$matches[2].'"><a href="'.$matches[3].'" title="'.$title_attrib.'">'.$menulabel.'</a>';
	else :
    	$filtered = '<li class="page_item page-item-'.$postID.$matches[2].'"><a href="'.$matches[3].'" title="'.$matches[4].'">'.$menulabel.'</a>';
	endif;
	
	return $filtered;
}

function lightseo_meta()
{
	global $post;
	
	$post_id = $post;
	
	if (is_object($post_id))
	{
		$post_id = $post_id->ID;
	}
	
 	$keywords = htmlspecialchars(stripcslashes(get_post_meta($post_id, '_lightseop_keywords', true)));
	$title = htmlspecialchars(stripcslashes(get_post_meta($post_id, '_lightseop_title', true)));
	$description = htmlspecialchars(stripcslashes(get_post_meta($post_id, '_lightseop_description', true)));
	$lightseo_meta = htmlspecialchars(stripcslashes(get_post_meta($post_id, '_lightseo_meta', true)));
	$lightseo_disable = htmlspecialchars(stripcslashes(get_post_meta($post_id, '_lightseop_disable', true)));
	$lightseo_titleatr = htmlspecialchars(stripcslashes(get_post_meta($post_id, '_lightseop_titleatr', true)));
	$lightseo_menulabel = htmlspecialchars(stripcslashes(get_post_meta($post_id, '_lightseop_menulabel', true)));	
	
?>
<script type="text/javascript">
function countChars(field, cntfield)
{
  cntfield.value = field.value.length;
}
</script>
  <input value="lightseo_edit" type="hidden" name="lightseo_edit" />
  <input type="hidden" name="nonce-lightseop-edit" value="<?php echo wp_create_nonce('edit-lightseop-nonce') ?>" />
  <table style="margin-bottom:40px">
    <tr>
      <th style="text-align:left;" colspan="2"></th>
    </tr>
    <tr>
      <th scope="row" style="text-align:right;">
        <?php _e('Title:', 'light_seo') ?>
      </th>
      <td>
        <input value="<?php echo $title ?>" type="text" name="lightseo_title" size="62" onkeydown="countChars(document.post.lightseo_title,document.post.lengthT)" onkeyup="countChars(document.post.lightseo_title,document.post.lengthT)" />
        <br />
        <input readonly="readonly" type="text" name="lengthT" size="3" maxlength="3" style="text-align:center;" value="<?php echo strlen($title);?>" />
        <?php _e(' characters. Most search engines use a maximum of 60 chars for the title.', 'light_seo') ?>
      </td>
    </tr>
    <tr>
      <th scope="row" style="text-align:right;">
        <?php _e('Description:', 'light_seo') ?>
      </th>
      <td>
        <textarea name="lightseo_description" rows="3" cols="60" onkeydown="countChars(document.post.lightseo_description,document.post.length1)"
          onkeyup="countChars(document.post.lightseo_description,document.post.length1)"><?php echo $description ?></textarea>
        <br />
        <input readonly="readonly" type="text" name="length1" size="3" maxlength="3" value="<?php echo strlen($description);?>" />
        <?php _e(' characters. Most search engines use a maximum of 160 chars for the description.', 'light_seo') ?>
      </td>
    </tr>
    <tr>
      <th scope="row" style="text-align:right;">
        <?php _e('Keywords (comma separated):', 'light_seo') ?>
      </th>
      <td>
        <input value="<?php echo $keywords ?>" type="text" name="lightseo_keywords" size="62"/>
      </td>
    </tr>
<?php if($post->post_type=='page') { ?>
    <tr>
      <th scope="row" style="text-align:right;">
        <?php _e('Title Attribute:', 'light_seo') ?>
      </th>
      <td>
        <input value="<?php echo $lightseo_titleatr ?>" type="text" name="lightseo_titleatr" size="62"/>
      </td>
    </tr>
    <tr>
      <th scope="row" style="text-align:right;">
        <?php _e('Menu Label:', 'light_seo') ?>
      </th>
      <td>
        <input value="<?php echo $lightseo_menulabel ?>" type="text" name="lightseo_menulabel" size="62"/>
      </td>
    </tr>
<?php } ?>
    <tr>
      <th scope="row" style="text-align:right; vertical-align:top;">
        <?php _e('Disable on this page/post:', 'light_seo')?>
      </th>
      <td>
        <input type="checkbox" name="lightseo_disable" <?php if ($lightseo_disable) echo 'checked="checked"'; ?>/>
      </td>
    </tr>
  </table>
<?php
}

function lightseo_meta_box_add()
{
	add_meta_box('lightseo',__('Light SEO', 'light_seo'), 'lightseo_meta', 'post');
	add_meta_box('lightseo',__('Light SEO', 'light_seo'), 'lightseo_meta', 'page');
}

if (($_POST['lightseo_enabled'] == null && $lightseop_options['lightseo_enabled'] != '1') || $_POST['lightseo_enabled'] == '0')
{
	add_action('admin_notices', 'lightseop_activation_notice');
}

if ($lightseop_options['lightseo_can'] == '1' || $lightseop_options['lightseo_can'] == 'on')
{
	remove_action('wp_head', 'rel_canonical');
}

add_action('admin_menu', 'lightseo_meta_box_add');
add_action('wp_list_pages', 'lightseop_list_pages');

$lightseo = new Light_SEO();

add_action('edit_post', array($lightseo, 'post_meta_tags'));
add_action('publish_post', array($lightseo, 'post_meta_tags'));
add_action('save_post', array($lightseo, 'post_meta_tags'));
add_action('edit_page_form', array($lightseo, 'post_meta_tags'));
add_action('init', array($lightseo, 'init'));
add_action('wp_head', array($lightseo, 'wp_head'));
add_action('template_redirect', array($lightseo, 'template_redirect'));
add_action('admin_menu', array($lightseo, 'admin_menu'));

?>
